# Bluesky — An Experiment Specification & Orchestration Engine

[![Build Status](https://img.shields.io/github/workflow/status/bluesky/bluesky/Unit%20Tests)](https://github.com/bluesky/bluesky/actions?query=workflow%3A%22Unit+Tests%22+branch%3Amaster)
[![PyPI](https://img.shields.io/pypi/v/bluesky)](https://pypi.org/project/bluesky/)
[![conda-forge](https://img.shields.io/conda/vn/conda-forge/bluesky)](https://anaconda.org/conda-forge/bluesky)

The Bluesky Python Package is an experiment specification and orchestration engine. 
- Specify the logic of an experiment in a high-level, hardware-abstracted way.
- First-class support for adaptive feedback between analysis and acquisition.
- Data is emitted in a streaming fashion in standard Python data structures.
- Pause/resume, robust error handling, and rich metadata capture are built in.

[**Bluesky Documentation**](http://blueskyproject.io/bluesky).

The Bluesky Project enables experimental science at the lab-bench or facility scale. It is a collection of Python libraries that are co-developed but independently useful and may be adopted *a la carte*.

[**Bluesky Project Documentation**](http://blueskyproject.io).

